@@ -2,14 +2,14 @@
 /**
  * Turba base inclusion file.
  *
- * $Horde: turba/lib/base.php,v 1.62.10.13 2006/03/10 23:55:37 chuck Exp $
+ * $Horde: turba/lib/base.php,v 1.62.10.17 2007/02/28 22:14:59 jan Exp $
  *
- * This file brings in all of the dependencies that every Turba script
- * will need, and sets up objects that all scripts use.
+ * This file brings in all of the dependencies that every Turba script will
+ * need, and sets up objects that all scripts use.
  */
 
-// Check for a prior definition of HORDE_BASE (perhaps by an
-// auto_prepend_file definition for site customization).
+// Check for a prior definition of HORDE_BASE (perhaps by an auto_prepend_file
+// definition for site customization).
 if (!defined('HORDE_BASE')) {
     @define('HORDE_BASE', dirname(__FILE__) . '/../..');
 }
@@ -44,8 +44,8 @@ require_once TURBA_BASE . '/lib/Turba.php';
 require_once TURBA_BASE . '/lib/Driver.php';
 
 // Turba source and attribute configuration.
-require TURBA_BASE . '/config/attributes.php';
-require TURBA_BASE . '/config/sources.php';
+include TURBA_BASE . '/config/attributes.php';
+include TURBA_BASE . '/config/sources.php';
 
 // Turba's Horde_Share object.
 require_once 'Horde/Share.php';
@@ -67,33 +67,36 @@ $GLOBALS['cfgSources'] = Turba::permissionsFilter($GLOBALS['cfgSources'], 'sourc
 $GLOBALS['attributes'] = $attributes;
 
 // Build the directory sources select widget.
-if (!isset($source)) {
-    $source = Util::getFormData('source', Turba::getDefaultAddressBook());
+$default_source = Util::nonInputVar('source');
+if (empty($default_source)) {
+    $default_source = empty($_SESSION['turba']['source']) ? Turba::getDefaultAddressBook() : $_SESSION['turba']['source'];
+    $default_source = Util::getFormData('source', $default_source);
 }
 $browse_source_options = '';
 $browse_source_count = 0;
 foreach (Turba::getAddressBooks() as $key => $curSource) {
     if (!empty($curSource['browse'])) {
-        $selected = ($key == $source) ? ' selected="selected"' : '';
+        $selected = ($key == $default_source) ? ' selected="selected"' : '';
         $browse_source_options .= '<option value="' . htmlspecialchars($key) . '" ' . $selected . '>' .
             htmlspecialchars($curSource['title']) . '</option>';
 
         $browse_source_count++;
 
-        if (empty($source)) {
-            $source = $key;
+        if (empty($default_source)) {
+            $default_source = $key;
         }
     }
 }
+$_SESSION['turba']['source'] = empty($cfgSources[$default_source]['browse']) ? Turba::getDefaultAddressBook() : $default_source;
 
-// Only set $add_source_options if there is at least one editable
-// address book that is not the current address book.
+// Only set $add_source_options if there is at least one editable address book
+// that is not the current address book.
 $addSources = Turba::getAddressBooks(PERMS_EDIT);
 $copymove_source_options = '';
 $copymoveSources = $addSources;
-unset($copymoveSources[$source]);
+unset($copymoveSources[$default_source]);
 foreach ($copymoveSources as $key => $curSource) {
-    if ($key != $source) {
+    if ($key != $default_source) {
         $copymove_source_options .= '<option value="' . htmlspecialchars($key) . '">' .
             htmlspecialchars($curSource['title']) . '</option>';
     }
